
// Test code for public release
// Ben Allanach 27.02.2001

#include "complex.h"
#include "def.h"
#include "linalg.h"
#include "lowe.h"
#include "rge.h"
#include "softsusy.h"
#include "susy.h"
#include "utils.h"
#include "numerics.h"

// User supplied routine. Inputs m at the unification scale, and uses
// inputParameters vector to output m with high energy soft boundary
// conditions. 
void sugraBcs(MssmSoftsusy & m, const DoubleVector & inputParameters)
{
  double m0 = inputParameters.display(1);
  double m12 = inputParameters.display(2);
  double a0 = inputParameters.display(3);

  // Sets scalar soft masses equal to m0, fermion ones to m12 and sets the
  // trilinear scalar coupling to be a0
  m.standardSugra(m0, m12, a0);
    
  return;
}

// outputs vector for use in above routine given SUGRA parameters 
// m0,m12,a0
void translateSugra(DoubleVector & pars, double m0, double m12,
			    double a0) 
{
  pars(1) = m0; pars(2) = m12; pars(3) = a0;
}

int main()
{
 // Sets format of output: 2 decimal places
  outputCharacteristics(4);

  cout << "\n\n\nSOFTSUSY test program, Ben Allanach 2001.\n";
  cout << "If you use SOFTSUSY, please refer to hep-ph/0104145\n\n\n";

  // Parameters used
  double m0 = 400., m12 = 400., a0 = 0., mgut = 1.9e16, tanb = 10.;
  int sgnMu = 1, accuracy = 3; // accuracy = 3 implies all loop/finite
				// corrections will be used

  // initialise the data from the input file "massIn"
  cout << "Low energy data:\n";
  QedQcd oneset;
  readIn(oneset, "massIn");

  // run the quark masses and QED,QCD gauge couplings (to 1 and 3 loops
  // respectively) up to MZ
  oneset.toMz();
  cout << "\nWith masses run to MZ (except top):\n" << oneset;

  DoubleVector pars(3); translateSugra(pars, m0, m12, a0);

  // Return r as an MssmSoftsusy object consistent with unification 
  // given by sugraBcs at mgut and the low energy data in oneset to 
  // accuracy epsilon
  const double epsilon = 1.0e-5;
  MssmSoftsusy r(lowOrg(sugraBcs, mgut, pars, sgnMu, tanb, oneset,
			 accuracy, epsilon));
  
  cout << "\nSoft SUSY object consistent with universal SUGRA and \nm0=" 
       << m0 << ", m12=" << m12 << ", a0=" << a0 << ":\n";
  cout << r;
  cout << "Problems with point: " << r.displayProblem();

  // Calculate fine tuning with respect to parameters given in pars (and
  // mu,B,ht)
  DoubleVector ft(6); ft = r.fineTune(sugraBcs, pars, mgut);  

  cout << "\n\nFine tuning vector with respect to (in order):" << endl
       << "user defined parameters, mu, B, ht, ie (m0,m12,a0,mu,B,ht)";
  cout << ft;
}
